Uses of Interface
org.astonbitecode.j4rs.api.Instance
Packages that use Instance
Package
Description
-
Uses of Instance in org.astonbitecode.j4rs.api
Methods in org.astonbitecode.j4rs.api that return InstanceModifier and TypeMethodDescriptionstatic <T> InstanceCasts a the object that is contained in a Instance to an object of class clazz.static <T> InstanceInstance.cloneInstance(Instance from) Clones a InstanceNativeInstantiation.createForStatic(String className) NativeInstantiation.createJavaArray(String className, InvocationArg... arg) Retrieves the instance held under the Field fieldNameNativeInstantiation.instantiate(String className, InvocationArg... arg) Instance.invoke(String methodName, InvocationArg... args) Invokes a method of the instance of the class that is set for thisInstanceInstance.invokeStatic(String methodName, InvocationArg... args) Invokes a static method of the class that is set for thisInstanceMethods in org.astonbitecode.j4rs.api with parameters of type InstanceModifier and TypeMethodDescriptionstatic <T> InstanceCasts a the object that is contained in a Instance to an object of class clazz.default <U> booleanInstance.checkEquals(Instance<U> other) static <T> InstanceInstance.cloneInstance(Instance from) Clones a Instance -
Uses of Instance in org.astonbitecode.j4rs.api.dtos
Classes in org.astonbitecode.j4rs.api.dtos that implement InstanceMethods in org.astonbitecode.j4rs.api.dtos that return InstanceModifier and TypeMethodDescriptionInvocationArg.getInstance()InvocationArg.invoke(String methodName, InvocationArg... args) InvocationArg.invokeStatic(String methodName, InvocationArg... args) Constructors in org.astonbitecode.j4rs.api.dtos with parameters of type InstanceModifierConstructorDescriptionInvocationArg(String className, Instance instance) InvocationArg(Instance instance) -
Uses of Instance in org.astonbitecode.j4rs.api.instantiation
Methods in org.astonbitecode.j4rs.api.instantiation that return InstanceModifier and TypeMethodDescriptionstatic InstanceNativeInstantiationImpl.createForStatic(String className) static InstanceNativeInstantiationImpl.createJavaArray(String className, InvocationArg... args) static InstanceNativeInstantiationImpl.createJavaList(String className, InvocationArg... args) static InstanceNativeInstantiationImpl.createJavaMap(String keyClassName, String valueClassName, InvocationArg... args) static InstanceNativeInstantiationImpl.instantiate(String className, InvocationArg... args) -
Uses of Instance in org.astonbitecode.j4rs.api.invocation
Classes in org.astonbitecode.j4rs.api.invocation that implement InstanceMethods in org.astonbitecode.j4rs.api.invocation that return InstanceModifier and TypeMethodDescriptionstatic <T> Instance<T> static <T> Instance<T> static <T> Instance<T> JsonInvocationImpl.invoke(String methodName, InvocationArg... args) JsonInvocationImpl.invokeStatic(String methodName, InvocationArg... args) -
Uses of Instance in org.astonbitecode.j4rs.api.java2rust
Methods in org.astonbitecode.j4rs.api.java2rust that return InstanceMethods in org.astonbitecode.j4rs.api.java2rust with parameters of type Instance -
Uses of Instance in org.astonbitecode.j4rs.api.services.delegates
Methods in org.astonbitecode.j4rs.api.services.delegates that return InstanceMethods in org.astonbitecode.j4rs.api.services.delegates with parameters of type Instance